@@ -57,7 +57,10 @@ use core::{
 		Iterator,
 		IntoIterator,
 	},
-	marker::PhantomData,
+	marker::{
+		PhantomData,
+		Send,
+	},
 	mem,
 	ops::{
 		Add,
@@ -600,6 +603,10 @@ where C: Cursor, T: 'a + Bits {
 	}
 }
 
+/// `BitBox` is safe to send across threads, but cannot be shared between them.
+unsafe impl<C, T> Send for BitBox<C, T>
+where C: Cursor, T: Bits {}
+
 impl<C, T> Add<Self> for BitBox<C, T>
 where C: Cursor, T: Bits {
 	type Output = Self;
